@@ -35,12 +35,10 @@
 #include <glib/gi18n.h>
 
 #include <gtk/gtk.h>
-#ifdef HAVE_NOTIFY
+#include <gconf/gconf-client.h>
 #include <libnotify/notify.h>
-#endif
 #include <packagekit-glib2/packagekit.h>
 #include <canberra-gtk.h>
-#include <gio/gio.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -55,10 +53,7 @@
 #include "gpk-task.h"
 
 static void     gpk_check_update_finalize	(GObject	     *object);
-
-#ifdef HAVE_NOTIFY
 static void	gpk_check_update_libnotify_cb (NotifyNotification *notification, gchar *action, gpointer data);
-#endif
 
 #define GPK_CHECK_UPDATE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPK_TYPE_CHECK_UPDATE, GpkCheckUpdatePrivate))
 
@@ -77,12 +72,12 @@ struct GpkCheckUpdatePrivate
 	gboolean		 icon_inhibit_update_in_progress;
 	gboolean		 icon_inhibit_network_offline;
 	gboolean		 icon_inhibit_update_viewer_connected;
-	GIcon			*gicon;
+	gchar			*icon_name;
 	PkTransactionList	*tlist;
 	PkControl		*control;
 	GpkAutoRefresh		*arefresh;
 	PkTask			*task;
-	GSettings		*settings;
+	GConfClient		*gconf_client;
 	guint			 number_updates_critical_last_shown;
 	NotifyNotification	*notification_updates_available;
 	NotifyNotification	*notification_error;
@@ -90,7 +85,6 @@ struct GpkCheckUpdatePrivate
 	guint			 updates_changed_id;
 	GCancellable		*cancellable;
 	PkError			*error_code;
-	GVolumeMonitor		*volume_monitor;
 };
 
 G_DEFINE_TYPE (GpkCheckUpdate, gpk_check_update, G_TYPE_OBJECT)
@@ -104,7 +98,7 @@ gpk_check_update_set_icon_visibility (GpkCheckUpdate *cupdate)
 	gboolean ret = FALSE;
 
 	/* check we have data */
-	if (cupdate->priv->gicon == NULL) {
+	if (cupdate->priv->icon_name == NULL) {
 		egg_debug ("not showing icon as nothing to show");
 		goto out;
 	}
@@ -128,7 +122,7 @@ gpk_check_update_set_icon_visibility (GpkCheckUpdate *cupdate)
 out:
 	/* show or hide icon */
 	if (ret) {
-		gtk_status_icon_set_from_gicon (cupdate->priv->status_icon, cupdate->priv->gicon);
+		gtk_status_icon_set_from_icon_name (cupdate->priv->status_icon, cupdate->priv->icon_name);
 		gtk_status_icon_set_visible (cupdate->priv->status_icon, TRUE);
 	} else {
 		gtk_status_icon_set_visible (cupdate->priv->status_icon, FALSE);
@@ -137,14 +131,13 @@ out:
 }
 
 /**
- * gpk_check_update_set_gicon:
+ * gpk_check_update_set_icon_name:
  **/
 static void
-gpk_check_update_set_gicon (GpkCheckUpdate *cupdate, GIcon *gicon)
+gpk_check_update_set_icon_name (GpkCheckUpdate *cupdate, const gchar *icon_name)
 {
-	if (cupdate->priv->gicon != NULL)
-		g_object_unref (cupdate->priv->gicon);
-	cupdate->priv->gicon = g_object_ref (gicon);
+	g_free (cupdate->priv->icon_name);
+	cupdate->priv->icon_name = g_strdup (icon_name);
 	gpk_check_update_set_icon_visibility (cupdate);
 }
 
@@ -388,9 +381,9 @@ gpk_check_update_finished_notify (GpkCheckUpdate *cupdate, PkResults *results)
 		g_string_set_size (message_text, message_text->len-1);
 
 	/* do we do the notification? */
-	ret = g_settings_get_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_UPDATE_COMPLETE);
+	ret = gconf_client_get_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_UPDATE_COMPLETE, NULL);
 	if (!ret) {
-		egg_debug ("ignoring due to GSettings");
+		egg_debug ("ignoring due to GConf");
 		goto out;
 	}
 
@@ -495,7 +488,6 @@ gpk_check_update_update_system_finished_cb (PkTask *task, GAsyncResult *res, Gpk
 	PkResults *results;
 	GError *error = NULL;
 	PkError *error_code = NULL;
-	guint timer_id;
 
 	/* get the results */
 	results = pk_task_generic_finish (task, res, &error);
@@ -504,12 +496,8 @@ gpk_check_update_update_system_finished_cb (PkTask *task, GAsyncResult *res, Gpk
 		g_error_free (error);
 
 		/* we failed, so re-get the update list */
-		gpk_check_update_set_gicon (cupdate, NULL);
-		timer_id = g_timeout_add_seconds (GPK_CHECK_UPDATE_FAILED_TASK_RECHECK_DELAY,
-						  (GSourceFunc) gpk_check_update_get_updates_post_update_cb, cupdate);
-#if GLIB_CHECK_VERSION(2,25,8)
-		g_source_set_name_by_id (timer_id, "[GpkCheckUpdate] failed");
-#endif
+		gpk_check_update_set_icon_name (cupdate, NULL);
+		g_timeout_add_seconds (GPK_CHECK_UPDATE_FAILED_TASK_RECHECK_DELAY, (GSourceFunc) gpk_check_update_get_updates_post_update_cb, cupdate);
 		goto out;
 	}
 
@@ -559,7 +547,6 @@ gpk_check_update_activate_update_cb (GtkStatusIcon *status_icon, GpkCheckUpdate
 	}
 }
 
-#ifdef HAVE_NOTIFY
 /**
  * gpk_check_update_libnotify_cb:
  **/
@@ -575,23 +562,23 @@ gpk_check_update_libnotify_cb (NotifyNotification *notification, gchar *action,
 	GpkCheckUpdate *cupdate = GPK_CHECK_UPDATE (data);
 
 	if (g_strcmp0 (action, "do-not-show-complete-restart") == 0) {
-		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_UPDATE_COMPLETE_RESTART);
-		g_settings_set_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_UPDATE_COMPLETE_RESTART, FALSE);
+		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_UPDATE_COMPLETE_RESTART);
+		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_UPDATE_COMPLETE_RESTART, FALSE, NULL);
 	} else if (g_strcmp0 (action, "do-not-show-complete") == 0) {
-		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_UPDATE_COMPLETE);
-		g_settings_set_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_UPDATE_COMPLETE, FALSE);
+		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_UPDATE_COMPLETE);
+		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_UPDATE_COMPLETE, FALSE, NULL);
 	} else if (g_strcmp0 (action, "do-not-show-update-started") == 0) {
-		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_UPDATE_STARTED);
-		g_settings_set_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_UPDATE_STARTED, FALSE);
+		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_UPDATE_STARTED);
+		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_UPDATE_STARTED, FALSE, NULL);
 	} else if (g_strcmp0 (action, "do-not-show-notify-critical") == 0) {
-		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_CRITICAL);
-		g_settings_set_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_CRITICAL, FALSE);
+		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_CRITICAL);
+		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_CRITICAL, FALSE, NULL);
 	} else if (g_strcmp0 (action, "do-not-show-update-not-battery") == 0) {
-		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_UPDATE_NOT_BATTERY);
-		g_settings_set_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_UPDATE_NOT_BATTERY, FALSE);
+		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_UPDATE_NOT_BATTERY);
+		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_UPDATE_NOT_BATTERY, FALSE, NULL);
 	} else if (g_strcmp0 (action, "distro-upgrade-do-not-show-available") == 0) {
-		egg_debug ("set %s to FALSE", GPK_SETTINGS_NOTIFY_DISTRO_UPGRADES);
-		g_settings_set_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_DISTRO_UPGRADES, FALSE);
+		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_DISTRO_UPGRADES);
+		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_DISTRO_UPGRADES, FALSE, NULL);
 	} else if (g_strcmp0 (action, "show-error-details") == 0) {
 		title = gpk_error_enum_to_localised_text (pk_error_get_code (cupdate->priv->error_code));
 		message = gpk_error_enum_to_localised_message (pk_error_get_code (cupdate->priv->error_code));
@@ -620,7 +607,6 @@ gpk_check_update_libnotify_cb (NotifyNotification *notification, gchar *action,
 	}
 	return;
 }
-#endif
 
 /**
  * gpk_check_update_critical_updates_warning:
@@ -637,9 +623,9 @@ gpk_check_update_critical_updates_warning (GpkCheckUpdate *cupdate, GPtrArray *a
 	g_return_if_fail (GPK_IS_CHECK_UPDATE (cupdate));
 
 	/* do we do the notification? */
-	ret = g_settings_get_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_CRITICAL);
+	ret = gconf_client_get_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_CRITICAL, NULL);
 	if (!ret) {
-		egg_debug ("ignoring due to GSettings");
+		egg_debug ("ignoring due to GConf");
 		return;
 	}
 
@@ -688,40 +674,74 @@ gpk_check_update_critical_updates_warning (GpkCheckUpdate *cupdate, GPtrArray *a
 }
 
 /**
- * gpk_check_update_get_status_icon:
+ * gpk_check_update_client_info_to_bitfield:
  **/
-static GIcon *
-gpk_check_update_get_status_icon (GpkCheckUpdate *cupdate, GPtrArray *array)
+static PkBitfield
+gpk_check_update_client_info_to_bitfield (GpkCheckUpdate *cupdate, GPtrArray *array)
 {
 	guint i;
-	PkPackage *package;
+	PkBitfield infos = 0;
+	PkPackage *item;
+	gchar **split;
 	PkInfoEnum info;
-	GIcon *icon = NULL;
+	gchar *package_id = NULL;
 
-	/* look for any urgent updates */
-	for (i = 0; i< array->len; i++) {
-		package = g_ptr_array_index (array, i);
-		info = pk_package_get_info (package);
-		if (info == PK_INFO_ENUM_SECURITY ||
-		    info == PK_INFO_ENUM_IMPORTANT) {
-			icon = g_themed_icon_new_with_default_fallbacks ("software-update-urgent-symbolic");
-			goto out;
-		}
+	g_return_val_if_fail (GPK_IS_CHECK_UPDATE (cupdate), PK_INFO_ENUM_UNKNOWN);
+
+	/* shortcut */
+	if (array->len == 0)
+		return PK_INFO_ENUM_UNKNOWN;
+
+	/* add each status to a array */
+	for (i=0; i<array->len; i++) {
+		item = g_ptr_array_index (array, i);
+		g_object_get (item,
+			      "info", &info,
+			      "package-id", &package_id,
+			      NULL);
+		split = pk_package_id_split (package_id);
+		egg_debug ("%s %s", split[PK_PACKAGE_ID_NAME], pk_info_enum_to_text (info));
+		g_strfreev (split);
+		pk_bitfield_add (infos, info);
+		g_free (package_id);
+	}
+	return infos;
+}
+
+/**
+ * gpk_check_update_get_best_update_icon:
+ **/
+static const gchar *
+gpk_check_update_get_best_update_icon (GpkCheckUpdate *cupdate, GPtrArray *array)
+{
+	gint value;
+	PkBitfield infos;
+	const gchar *icon;
+
+	g_return_val_if_fail (GPK_IS_CHECK_UPDATE (cupdate), NULL);
+
+	/* get an enumerated array with all the update types */
+	infos = gpk_check_update_client_info_to_bitfield (cupdate, array);
+
+	/* get the most important icon */
+	value = pk_bitfield_contain_priority (infos,
+					      PK_INFO_ENUM_SECURITY,
+					      PK_INFO_ENUM_IMPORTANT,
+					      PK_INFO_ENUM_BUGFIX,
+					      PK_INFO_ENUM_NORMAL,
+					      PK_INFO_ENUM_ENHANCEMENT,
+					      PK_INFO_ENUM_LOW,
+					      PK_INFO_ENUM_BLOCKED, -1);
+	if (value == -1) {
+		egg_warning ("should not be possible!");
+		value = PK_INFO_ENUM_LOW;
+	} else if (value == PK_INFO_ENUM_BLOCKED) {
+		/* all updates are blocked */
+		return NULL;
 	}
 
-	/* look for any normal updates */
-	for (i = 0; i< array->len; i++) {
-		package = g_ptr_array_index (array, i);
-		info = pk_package_get_info (package);
-		if (info == PK_INFO_ENUM_BUGFIX ||
-		    info == PK_INFO_ENUM_NORMAL ||
-		    info == PK_INFO_ENUM_ENHANCEMENT ||
-		    info == PK_INFO_ENUM_LOW) {
-			icon = g_themed_icon_new_with_default_fallbacks ("software-update-available-symbolic");
-			goto out;
-		}
-	}
-out:
+	/* get the icon */
+	icon = gpk_info_enum_to_icon_name (value);
 	return icon;
 }
 
@@ -738,7 +758,7 @@ gpk_check_update_check_on_battery (GpkCheckUpdate *cupdate)
 
 	g_return_val_if_fail (GPK_IS_CHECK_UPDATE (cupdate), FALSE);
 
-	ret = g_settings_get_boolean (cupdate->priv->settings, GPK_SETTINGS_UPDATE_BATTERY);
+	ret = gconf_client_get_bool (cupdate->priv->gconf_client, GPK_CONF_UPDATE_BATTERY, NULL);
 	if (ret) {
 		egg_debug ("okay to update due to policy");
 		return TRUE;
@@ -751,9 +771,9 @@ gpk_check_update_check_on_battery (GpkCheckUpdate *cupdate)
 	}
 
 	/* do we do the notification? */
-	ret = g_settings_get_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_UPDATE_NOT_BATTERY);
+	ret = gconf_client_get_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_UPDATE_NOT_BATTERY, NULL);
 	if (!ret) {
-		egg_debug ("ignoring due to GSettings");
+		egg_debug ("ignoring due to GConf");
 		return FALSE;
 	}
 
@@ -780,6 +800,27 @@ gpk_check_update_check_on_battery (GpkCheckUpdate *cupdate)
 	return FALSE;
 }
 
+/**
+ * gpk_check_update_get_update_policy:
+ **/
+static GpkUpdateEnum
+gpk_check_update_get_update_policy (GpkCheckUpdate *cupdate)
+{
+	GpkUpdateEnum update;
+	gchar *updates;
+
+	g_return_val_if_fail (GPK_IS_CHECK_UPDATE (cupdate), FALSE);
+
+	updates = gconf_client_get_string (cupdate->priv->gconf_client, GPK_CONF_AUTO_UPDATE, NULL);
+	if (updates == NULL) {
+		egg_warning ("'%s' gconf key is null!", GPK_CONF_AUTO_UPDATE);
+		return GPK_UPDATE_ENUM_UNKNOWN;
+	}
+	update = gpk_update_enum_from_text (updates);
+	g_free (updates);
+	return update;
+}
+
 /**
  * gpk_check_update_notify_doing_updates:
  **/
@@ -790,8 +831,8 @@ gpk_check_update_notify_doing_updates (GpkCheckUpdate *cupdate)
 	GError *error = NULL;
 	NotifyNotification *notification;
 
-	/* in GSettings? */
-	ret = g_settings_get_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_CRITICAL);
+	/* in GConf? */
+	ret = gconf_client_get_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_CRITICAL, NULL);
 	if (!ret)
 		goto out;
 
@@ -832,7 +873,7 @@ gpk_check_update_get_updates_finished_cb (GObject *object, GAsyncResult *res, Gp
 	GString *status_tooltip = NULL;
 	GpkUpdateEnum update;
 	GPtrArray *security_array = NULL;
-	GIcon *icon = NULL;
+	const gchar *icon;
 	gchar **package_ids;
 	GPtrArray *array = NULL;
 	PkError *error_code = NULL;
@@ -862,7 +903,7 @@ gpk_check_update_get_updates_finished_cb (GObject *object, GAsyncResult *res, Gp
 	/* we have no updates */
 	if (array->len == 0) {
 		egg_debug ("no updates");
-		gpk_check_update_set_gicon (cupdate, NULL);
+		gpk_check_update_set_icon_name (cupdate, NULL);
 		goto out;
 	}
 
@@ -879,13 +920,13 @@ gpk_check_update_get_updates_finished_cb (GObject *object, GAsyncResult *res, Gp
 	}
 
 	/* work out icon */
-	icon = gpk_check_update_get_status_icon (cupdate, array);
+	icon = gpk_check_update_get_best_update_icon (cupdate, array);
 	if (icon == NULL) {
 		egg_debug ("all updates blocked");
-		gpk_check_update_set_gicon (cupdate, NULL);
+		gpk_check_update_set_icon_name (cupdate, NULL);
 		goto out;
 	}
-	gpk_check_update_set_gicon (cupdate, icon);
+	gpk_check_update_set_icon_name (cupdate, icon);
 
 	/* TRANSLATORS: tooltip: how many updates are waiting to be applied */
 	g_string_append_printf (status_tooltip, ngettext ("There is %d update available",
@@ -899,7 +940,7 @@ gpk_check_update_get_updates_finished_cb (GObject *object, GAsyncResult *res, Gp
 	}
 
 	/* do we do the automatic updates? */
-	update = g_settings_get_enum (cupdate->priv->settings, GPK_SETTINGS_AUTO_UPDATE);
+	update = gpk_check_update_get_update_policy (cupdate);
 	if (update == GPK_UPDATE_ENUM_UNKNOWN) {
 		egg_warning ("policy unknown");
 		goto out;
@@ -976,8 +1017,6 @@ gpk_check_update_get_updates_finished_cb (GObject *object, GAsyncResult *res, Gp
 	/* shouldn't happen */
 	egg_warning ("unknown update mode");
 out:
-	if (icon != NULL)
-		g_object_unref (icon);
 	if (error_code != NULL)
 		g_object_unref (error_code);
 	if (status_tooltip != NULL)
@@ -1056,7 +1095,9 @@ gpk_check_update_query_updates (GpkCheckUpdate *cupdate)
 	}
 
 	/* get new update list */
-	pk_client_get_updates_async (PK_CLIENT(cupdate->priv->task), PK_FILTER_ENUM_NONE, cupdate->priv->cancellable, NULL, NULL,
+	pk_client_get_updates_async (PK_CLIENT(cupdate->priv->task),
+				     pk_bitfield_value (PK_FILTER_ENUM_NONE),
+				     cupdate->priv->cancellable, NULL, NULL,
 				     (GAsyncReadyCallback) gpk_check_update_get_updates_finished_cb, cupdate);
 out:
 	return;
@@ -1085,7 +1126,7 @@ gpk_check_update_updates_changed_cb (PkControl *control, GpkCheckUpdate *cupdate
 	g_return_if_fail (GPK_IS_CHECK_UPDATE (cupdate));
 
 	/* if we don't want to auto check for updates, don't do this either */
-	thresh = g_settings_get_int (cupdate->priv->settings, GPK_SETTINGS_FREQUENCY_GET_UPDATES);
+	thresh = gconf_client_get_int (cupdate->priv->gconf_client, GPK_CONF_FREQUENCY_GET_UPDATES, NULL);
 	if (thresh == 0) {
 		egg_debug ("not when policy is to never get updates");
 		return;
@@ -1095,15 +1136,14 @@ gpk_check_update_updates_changed_cb (PkControl *control, GpkCheckUpdate *cupdate
 	if (cupdate->priv->updates_changed_id > 0)
 		g_source_remove (cupdate->priv->updates_changed_id);
 
+	/* hiding icon, as it's probably inaccurate */
+	gpk_check_update_set_icon_name (cupdate, NULL);
+
 	/* now try to get newest update list */
 	egg_debug ("updates changed, so getting new update list in %is", GPK_CHECK_UPDATE_UPDATES_CHANGED_TIMEOUT);
 	cupdate->priv->updates_changed_id =
 		g_timeout_add_seconds (GPK_CHECK_UPDATE_UPDATES_CHANGED_TIMEOUT,
 				       (GSourceFunc) gpk_check_update_query_updates_changed_cb, cupdate);
-#if GLIB_CHECK_VERSION(2,25,8)
-	g_source_set_name_by_id (cupdate->priv->updates_changed_id,
-				 "[GpkCheckUpdate] updates-changed");
-#endif
 }
 
 /**
@@ -1263,9 +1303,9 @@ gpk_check_update_get_distro_upgrades_finished_cb (GObject *object, GAsyncResult
 	}
 
 	/* do we do the notification? */
-	ret = g_settings_get_boolean (cupdate->priv->settings, GPK_SETTINGS_NOTIFY_DISTRO_UPGRADES);
+	ret = gconf_client_get_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_DISTRO_UPGRADES, NULL);
 	if (!ret) {
-		egg_debug ("ignoring due to GSettings");
+		egg_debug ("ignoring due to GConf");
 		goto out;
 	}
 
@@ -1398,72 +1438,6 @@ out:
 	return;
 }
 
-/**
- * gpk_check_update_file_exist_in_root:
- */
-static gboolean
-gpk_check_update_file_exist_in_root (const gchar *root, const gchar *filename)
-{
-	gboolean ret;
-	GFile *source;
-	gchar *source_path;
-
-	source_path = g_build_filename (root, filename, NULL);
-	source = g_file_new_for_path (source_path);
-
-	/* an interesting file exists */
-	ret = g_file_query_exists (source, NULL);
-	egg_debug ("checking for %s: %s", source_path, ret ? "yes" : "no");
-	if (!ret)
-		goto out;
-out:
-	g_free (source_path);
-	g_object_unref (source);
-	return ret;
-}
-
-/**
- * gpk_check_update_mount_added_cb:
- */
-static void
-gpk_check_update_mount_added_cb (GVolumeMonitor *volume_monitor, GMount *mount, GpkCheckUpdate *cupdate)
-{
-	gboolean ret = FALSE;
-	gchar **filenames = NULL;
-	gchar *media_repo_filenames;
-	gchar *root_path;
-	GFile *root;
-	guint i;
-
-	/* check if any installed media is an install disk */
-	root = g_mount_get_root (mount);
-	root_path = g_file_get_path (root);
-
-	/* use settings */
-	media_repo_filenames = g_settings_get_string (cupdate->priv->settings, GPK_SETTINGS_MEDIA_REPO_FILENAMES);
-	if (media_repo_filenames == NULL) {
-		egg_warning ("failed to get media repo filenames");
-		goto out;
-	}
-
-	/* search each possible filename */
-	filenames = g_strsplit (media_repo_filenames, ",", -1);
-	for (i=0; filenames[i] != NULL; i++) {
-		ret = gpk_check_update_file_exist_in_root (root_path, filenames[i]);
-		if (ret)
-			break;
-	}
-
-	/* do an updates check with the new media */
-	if (ret)
-		gpk_check_update_query_updates (cupdate);
-out:
-	g_strfreev (filenames);
-	g_free (media_repo_filenames);
-	g_free (root_path);
-	g_object_unref (root);
-}
-
 /**
  * gpk_check_update_init:
  * @cupdate: This class instance
@@ -1479,12 +1453,16 @@ gpk_check_update_init (GpkCheckUpdate *cupdate)
 	cupdate->priv->updates_changed_id = 0;
 	cupdate->priv->notification_updates_available = NULL;
 	cupdate->priv->notification_error = NULL;
-	cupdate->priv->gicon = NULL;
+	cupdate->priv->icon_name = NULL;
 	cupdate->priv->number_updates_critical_last_shown = 0;
 	cupdate->priv->status_icon = gtk_status_icon_new ();
 	cupdate->priv->cancellable = g_cancellable_new ();
 	cupdate->priv->error_code = NULL;
-	cupdate->priv->settings = g_settings_new (GPK_SETTINGS_SCHEMA);
+
+	/* preload all the common GConf keys */
+	cupdate->priv->gconf_client = gconf_client_get_default ();
+	gconf_client_add_dir (cupdate->priv->gconf_client, GPK_CONF_DIR,
+			      GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 
 	cupdate->priv->arefresh = gpk_auto_refresh_new ();
 	g_signal_connect (cupdate->priv->arefresh, "refresh-cache",
@@ -1511,10 +1489,6 @@ gpk_check_update_init (GpkCheckUpdate *cupdate)
 	g_signal_connect (cupdate->priv->dbus_monitor_viewer, "connection-changed",
 			  G_CALLBACK (gpk_cupdate_connection_changed_cb), cupdate);
 
-	/* get a volume monitor so we can watch media */
-	cupdate->priv->volume_monitor = g_volume_monitor_get ();
-	g_signal_connect (cupdate->priv->volume_monitor, "mount-added", G_CALLBACK (gpk_check_update_mount_added_cb), cupdate);
-
 	/* use an asynchronous query object */
 	cupdate->priv->task = PK_TASK (gpk_task_new ());
 	g_object_set (cupdate->priv->task,
@@ -1566,14 +1540,12 @@ gpk_check_update_finalize (GObject *object)
 	g_object_unref (cupdate->priv->status_icon);
 	g_object_unref (cupdate->priv->tlist);
 	g_object_unref (cupdate->priv->arefresh);
-	g_object_unref (cupdate->priv->settings);
+	g_object_unref (cupdate->priv->gconf_client);
 	g_object_unref (cupdate->priv->control);
 	g_object_unref (cupdate->priv->task);
 	g_object_unref (cupdate->priv->dbus_monitor_viewer);
 	g_object_unref (cupdate->priv->cancellable);
-	g_object_unref (cupdate->priv->volume_monitor);
-	if (cupdate->priv->gicon != NULL)
-		g_object_unref (cupdate->priv->gicon);
+	g_free (cupdate->priv->icon_name);
 	if (cupdate->priv->error_code != NULL)
 		g_object_unref (cupdate->priv->error_code);
 	if (cupdate->priv->updates_changed_id > 0)
